package
Version:
v0.0.1
Opens a new window with list of versions in this module.
Published: Dec 9, 2024
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type FileResponse struct {
ID string `json:"file_id"`
FileName string `json:"file_name"`
Path string `json:"file_path"`
Description string `json:"description,omitempty"`
CreatedAt string `json:"created_at"`
Size int64 `json:"file_size"`
}
type UploadFileRequest struct {
FileName string `form:"file_name,omitempty" validate:"omitempty,min=1,max=255"`
FilePath string `form:"file_path,omitempty"`
Description string `form:"description,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.